pilas.evento.AttrDict

Package pilas :: Module evento :: Class AttrDict |
[hide private]
[frames] | no frames]

# Class AttrDict

source code

    object --+
             |
          dict --+
                 |
                AttrDict

Envoltorio para que el diccionario de eventos se pueda acceder usando como si tuviera attributos de objeto.

Por ejemplo, con esta clase es posible que un diccionario se pueda usar así:

    >>> b = AttrDict({'x': 123})
    >>> b.x
    123
    >>> b['x']
    123

Instance Methods | [hide private]
    new empty dictionary
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__getattr__(self, name) | source code
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `dict`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)